@@ -1,5 +1,5 @@
 from abc import ABC, abstractmethod
-from typing import NamedTuple
+from typing import NamedTuple, Union
 
 from odd_models.models import DataEntityList
 
@@ -9,16 +9,26 @@ from odd_collector_sdk.domain.plugin import Plugin
 class AbstractAdapter(ABC):
     @abstractmethod
     def get_data_source_oddrn(self) -> str:
-        raise NotImplementedError()
+        pass
 
     @abstractmethod
     def get_data_entity_list(self) -> DataEntityList:
-        raise NotImplementedError()
+        pass
+
+
+class AsyncAbstractAdapter(ABC):
+    @abstractmethod
+    async def get_data_source_oddrn(self) -> str:
+        pass
+
+    @abstractmethod
+    async def get_data_entity_list(self) -> DataEntityList:
+        pass
 
 
 AdapterConfig = Plugin
 
 
 class Adapter(NamedTuple):
-    adapter: AbstractAdapter
+    adapter: Union[AbstractAdapter, AsyncAbstractAdapter]
     config: AdapterConfig
